@@ -5,7 +5,7 @@ use Test::Builder::Module;
 use Test::Name::FromLine;
 use Text::MatchedPosition;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 our @ISA = qw/Test::Builder::Module/;
 
@@ -501,6 +501,10 @@ Test::Arrow - Object-Oriented testing library
         ->got(2 * 3)
         ->is_num;
 
+    $arr->expected(qr/^ab/)
+        ->got('abc')
+        ->like;
+
     # `unlike` shows where a place could have matched if it's failed
     $arr->name('Unlike Fail example')
         ->expected(qr/b/)
@@ -512,8 +516,8 @@ Test::Arrow - Object-Oriented testing library
     #           matches '(?^:b)'
     #           matched at line: 1, offset: 2
 
-    $arr->throw(sub { die 'Baz' })->catch(qr/^Ba/);
     $arr->warnings(sub { warn 'Bar' })->catch(qr/^Ba/);
+    $arr->throw(sub { die 'Baz' })->catch(qr/^Ba/);
 
 
 =head1 DESCRIPTION
@@ -591,9 +595,9 @@ The test name is taken from the first line of each test.
 
 =head2 TEST EXECUTERS
 
-=head3 pass
+=head3 pass($test_name)
 
-=head3 fail
+=head3 fail($test_name)
 
 Just pass or fail
 
@@ -647,7 +651,7 @@ Checks to make sure the $class or $object can do these @methods
 
     $arr->got($got_object)->expected($class)->isa_ok;
 
-Checks to see if the given C<$got_object-&gt;isa($class)>. Also checks to make sure the object was defined in the first place.
+Checks to see if the given C<$got_object-E<gt>isa($class)>. Also checks to make sure the object was defined in the first place.
 
 It works on references, too:
 
@@ -749,24 +753,20 @@ B<Note> that you must never put C<done_testing> inside an C<END { ... }> block.
 
 =head3 done
 
-Alias of done_testing
+Alias of C<done_testing>
 
 =head2 CONSTANTS
 
-=head3 PASS
+=head3 PASS = 1
 
-1
-
-=head3 FAIL
-
-0
+=head3 FAIL = 0
 
 
 =head1 REPOSITORY
 
 =begin html
 
-<a href="https://github.com/bayashi/Test-Arrow/blob/master/README.pod"><img src="https://img.shields.io/badge/Version-0.10-green?style=flat"></a> <a href="https://github.com/bayashi/Test-Arrow/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/Test-Arrow/actions"><img src="https://github.com/bayashi/Test-Arrow/workflows/master/badge.svg?_t=1582780893"/></a> <a href="https://coveralls.io/r/bayashi/Test-Arrow"><img src="https://coveralls.io/repos/bayashi/Test-Arrow/badge.png?_t=1582780893&branch=master"/></a>
+<a href="https://github.com/bayashi/Test-Arrow/blob/master/README.pod"><img src="https://img.shields.io/badge/Version-0.11-green?style=flat"></a> <a href="https://github.com/bayashi/Test-Arrow/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/Test-Arrow/actions"><img src="https://github.com/bayashi/Test-Arrow/workflows/master/badge.svg?_t=1582822443"/></a> <a href="https://coveralls.io/r/bayashi/Test-Arrow"><img src="https://coveralls.io/repos/bayashi/Test-Arrow/badge.png?_t=1582822443&branch=master"/></a>
 
 =end html
 
@@ -786,7 +786,7 @@ L<Test::More>
 
 L<Test::Kantan> - A behavior-driven development framework
 
-L<Test::Builder::Module>
+L<Test::Builder>
 
 L<Test::Name::FromLine>
 
